@@ -6,7 +6,7 @@ import pytest
 from pydantic import UUID4
 from sqlalchemy import exc
 from sqlalchemy.ext.asyncio import AsyncEngine, AsyncSession, create_async_engine
-from sqlalchemy.ext.declarative import DeclarativeMeta, declarative_base
+from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import sessionmaker
 
 from fastapi_users_db_sqlalchemy import SQLAlchemyBaseUserTableUUID
@@ -15,7 +15,7 @@ from fastapi_users_db_sqlalchemy.access_token import (
     SQLAlchemyBaseAccessTokenTableUUID,
 )
 
-Base: DeclarativeMeta = declarative_base()
+Base = declarative_base()
 
 
 class AccessToken(SQLAlchemyBaseAccessTokenTableUUID, Base):
@@ -61,7 +61,6 @@ async def sqlalchemy_access_token_db(
 
 
 @pytest.mark.asyncio
-@pytest.mark.db
 async def test_queries(
     sqlalchemy_access_token_db: SQLAlchemyAccessTokenDatabase[AccessToken],
     user_id: UUID4,
@@ -113,7 +112,6 @@ async def test_queries(
 
 
 @pytest.mark.asyncio
-@pytest.mark.db
 async def test_insert_existing_token(
     sqlalchemy_access_token_db: SQLAlchemyAccessTokenDatabase[AccessToken],
     user_id: UUID4,
